@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ca">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
 <context>
     <name>MainWindow</name>
     <message>
@@ -374,7 +372,7 @@ Esteu segurs que voleu continuar?</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="194"/>
-        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,
+        <source>Writing %1 using 'dd' command to /dev/%2,
 
 Please wait until the process is completed</source>
         <translation>Enregistrant %1 usant l&apos;ordre &apos;dd&apos; a /dev/%2,
@@ -568,4 +566,4 @@ Si us plau, espereu fins que el procés s&apos;hagi acabat</translation>
         <translation>versió:</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
