@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ru_RU">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru_RU">
 <context>
     <name>MainWindow</name>
     <message>
@@ -374,7 +372,7 @@ Are you sure you want to proceed?</source>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="194"/>
-        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,
+        <source>Writing %1 using 'dd' command to /dev/%2,
 
 Please wait until the process is completed</source>
         <translation>Записывается %1 с помощью «dd» на /dev/%2,
@@ -569,4 +567,4 @@ Please wait until the process is completed</source>
         <translation>версия:</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
