@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sv">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sv">
 <context>
     <name>MainWindow</name>
     <message>
@@ -374,7 +372,7 @@ Detta kan indikera att du har valt fel enhet.
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="194"/>
-        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,
+        <source>Writing %1 using 'dd' command to /dev/%2,
 
 Please wait until the process is completed</source>
         <translation>Skriver %1 med &apos;dd&apos; kommando till /dev/%2,
@@ -569,4 +567,4 @@ Var vänlig vänta tills processen är klar</translation>
         <translation>version:</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
